import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post } from '../../services/api';

/**
 * Fetch notifications from the API
 */
export const fetchNotifications = createAsyncThunk(
    'notificationCenter/fetchNotifications',
    async (_, { rejectWithValue }) => {
        try {
            const response = await get('/notifications/');
            return response;
        } catch (error) {
            const errorMessage = error.response?.data?.message || 'Failed to fetch notifications';
            return rejectWithValue(errorMessage);
        }
    }
);

/**
 * Mark a notification as read
 */
export const markNotificationRead = createAsyncThunk(
    'notificationCenter/markNotificationRead',
    async (notificationId, { rejectWithValue }) => {
        try {
            const response = await post(`/notifications/${notificationId}/mark-as-read/`);
            return { id: notificationId, ...response };
        } catch (error) {
			const errorMessage = error.response?.data?.message || 'Failed to mark notification as read';
            return rejectWithValue(errorMessage);
        }
    }
);

/**
 * Mark all notifications as read
 */
export const markAllNotificationsRead = createAsyncThunk(
    'notificationCenter/markAllNotificationsRead',
    async (_, { rejectWithValue }) => {
        try {
            const response = await post('/notifications/mark-all-as-read/');
            return response;
        } catch (error) {
            const errorMessage = error.response?.data?.message || 'Failed to mark all notifications as read';
            return rejectWithValue(errorMessage);
        }
    }
);
